#!/bin/sh

set -e

##functions.sh##

target="$1"
self="$2"
md5sum="${self%.sh}.md5sum"
flags="$3"

generated="$CCLUB_CONFIG_GENERATED_DIR/cacheinfo"

afscache="/var/cache/openafs"
if mount | grep -F -q " on $afscache "; then
    :
elif [ -z "$CCLUB_CONFIG_ALLOW_NON_DEDICATED_AFSCACHE" -a \
       ! -e "$CCLUB_CONFIG_FLAGS_DIR/allow-non-dedicated-afscache" ]; then
    echo "failing, $afscache is not its own partition" 1>&2
    exit 1
else
    non_dedicated=1
fi

if [ ! -e "$afscache" ]; then
    (umask 077; mkdir -p "$afscache")
fi

space=`df -k --output=size,avail "$afscache" | tail -n +2 |
           sed -e 's/^ *//' -e 's/ *$//' -e 's/ \+/ /g'`
total_kbytes=`echo "$space" | cut -d " " -f 1`
avail_kbytes=`echo "$space" | cut -d " " -f 2`
if [ -z "$total_kbytes" -o -z "$avail_kbytes" ]; then
    echo "could not get space information for $afscache" 1>&2
    exit 1
fi

if [ -z "$non_dedicated" ]; then
    size=`expr $total_kbytes \* 9 / 10`
else
    size=`expr $total_kbytes / 10`
    alt_size=`expr $avail_kbytes \* 3 / 10`
    if [ $size -gt $alt_size ]; then
        size=$alt_size
    fi
    if [ $size -gt 1000000 ]; then
        size=1000000
    fi
fi
size=`expr $size - \( $size % 10000 \)`

if [ $size -lt 100000 ]; then
    echo "calculated cache size ($size) is too small" 1>&2
    exit 1
fi

echo "/afs:$afscache:$size" > "$generated"
cp -pf "$md5sum" "${generated}.md5sum"

configure_via_copy "$target" "$generated" "$flags"

if [ -n "$non_dedicated" ]; then
    touch "$CCLUB_CONFIG_FLAGS_DIR/allow-non-dedicated-afscache"
fi
